@@ -2,6 +2,7 @@ import hashlib
 import json
 import pickle
 import time
+from functools import wraps
 from os.path import expanduser
 from pathlib import Path
 
@@ -401,6 +402,7 @@ def need_authentication():
     """
 
     def decorator(func):
+        @wraps(func)
         def wrapper(self, *args, **kwargs):
             self.authentication.refresh_if_needed()
             result = func(self, *args, **kwargs)
