@@ -111,6 +111,9 @@ class Entity:
             elg.Entity: Entity object.
         """
         result["domain"] = get_domain(domain=domain)
+        # Add default value here because this field is not returned by the catalog in the dev cluster
+        if "functional_service" not in result.keys():
+            result["functional_service"] = True 
         # Add default value to the status parameter as it has been removed from the search API result
         if "status" not in result.keys():
             result["status"] = None
