@@ -15,7 +15,7 @@ try:
     from requests_toolbelt import MultipartDecoder
 except:
     raise ImportError(
-        "Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[provider]`."
+        "Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[flask]`."
     )
 
 from .model import AudioRequest, StructuredTextRequest, TextRequest
@@ -25,7 +25,7 @@ from .utils.docker import COPY_FOLDER, DOCKERFILE, ENTRYPOINT_FLASK
 class FlaskService:
     """
     Class to help the creation of an ELG compatible service from a python model.
-    Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[provider]`.
+    Extra dependencies need to be install to use the FlaskService class. Please run: `pip install elg[flask]`.
     """
 
     requirements = ["gunicorn", "elg[flask]"]
