@@ -27,7 +27,7 @@ class AnnotationsResponse(ResponseObject):
         validator: ensures either the "features" or "annotations" fields are present
         """
         features, annotations = values.get("features"), values.get("annotations")
-        if not (bool(features) ^ bool(annotations)):
+        if features is None and annotations is None:
             raise ValueError('A annotation response must have either "features" or "annotations" fields')
         return values
 
