@@ -1,5 +1,5 @@
 ENTRYPOINT_FLASK = """\
-#!/bin/sh\nexec /sbin/tini -- venv/bin/gunicorn --bind=0.0.0.0:8000 "--workers=$WORKERS" --worker-tmp-dir=/dev/shm "$@" {service_script}:app\n"""
+#!/bin/sh\nexec /sbin/tini -- venv/bin/gunicorn --bind=0.0.0.0:8000 "--workers=$WORKERS" "--workers=$TIMEOUT" --worker-tmp-dir=/dev/shm "$@" {service_script}:app\n"""
 
 ENTRYPOINT_QUART = """\
 #!/bin/sh\nexec /sbin/tini -- venv/bin/hypercorn --bind=0.0.0.0:8000 "$@" {service_script}:app\n"""
@@ -29,6 +29,7 @@ RUN venv/bin/pip --no-cache-dir install -r requirements.txt
 COPY --chown=elg:elg docker-entrypoint.sh {required_files} /elg/
 
 ENV WORKERS=1
+ENV TIMEOUT=30
 
 RUN chmod +x ./docker-entrypoint.sh
 ENTRYPOINT ["./docker-entrypoint.sh"]\
